const axios = require('axios')
const fs = require('fs')
const extractZip = require('extract-zip')

const downloadUrl =
  'https://github.com/alfianandinugraha/create-react-typescript-app/archive/refs/heads/main.zip'
const projectName = 'template'
const currentDir = process.cwd()

axios
  .get(downloadUrl, {
    responseType: 'stream',
  })
  .then(async (response) => {
    const writeStream = fs.createWriteStream('crta.zip')

    response.data.pipe(writeStream)

    writeStream.on('finish', async () => {
      try {
        await extractZip('crta.zip', { dir: currentDir })
        fs.renameSync('create-react-typescript-app-main', projectName)
        fs.renameSync(`${projectName}/.gitignore`, `${projectName}/gitignore`)
        fs.unlinkSync('crta.zip')

        const templatePackage = fs.readFileSync('./template/package.json')
        const { dependencies, devDependencies, scripts } = JSON.parse(templatePackage)

        const newTemplate = {
          package: {
            dependencies, devDependencies,
            scripts
          }
        }
        fs.writeFileSync('./template.json', JSON.stringify(newTemplate, null, 2) + '\n')
        fs.unlinkSync('./template/package.json')
        fs.unlinkSync('./template/CONTRIBUTING.md')
        fs.unlinkSync('./template/LICENSE')
      } catch (err) {
        fs.unlinkSync('crta.zip')
        console.log(`❌ ${err.message}`)
      }

      try {
        fs.unlinkSync('./template/yarn.lock')
        fs.unlinkSync('./template/package-lock.json')
      } catch (err) {
      }
    })
  })
  .catch((err) => {
    console.log(`❌ Download failed`)
    console.log(`❌ ${err.message}\n`)
    console.log('Please check your internet connection')
  })